package com.sundot.airport.item.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.sundot.airport.item.domain.ItemSeizureRecord;
import com.sundot.airport.item.domain.ItemSeizureRecordDTO;

/**
 * 查获记录Service接口
 *
 * @author ruoyi
 * @date 2025-07-08
 */
public interface IItemSeizureRecordService extends IService<ItemSeizureRecord> {
    /**
     * 查询查获记录
     *
     * @param id 查获记录主键
     * @return 查获记录
     */
    public ItemSeizureRecord selectItemSeizureRecordById(Long id);

    /**
     * 查询查获记录列表（用于导出）
     *
     * @param itemSeizureRecord 查获记录
     * @return 查获记录集合
     */
    public List<ItemSeizureRecord> selectItemSeizureRecordListForExport(ItemSeizureRecordDTO itemSeizureRecord);

    /**
     * 查询查获记录列表
     *
     * @param itemSeizureRecord 查获记录
     * @return 查获记录集合
     */
    public List<ItemSeizureRecord> selectItemSeizureRecordList(ItemSeizureRecordDTO itemSeizureRecord);

    /**
     * 新增查获记录
     *
     * @param itemSeizureRecord 查获记录
     * @return 结果
     */
    public Long insertItemSeizureRecord(ItemSeizureRecord itemSeizureRecord);

    /**
     * 修改查获记录
     *
     * @param itemSeizureRecord 查获记录
     * @return 结果
     */
    public int updateItemSeizureRecord(ItemSeizureRecord itemSeizureRecord);

    /**
     * 批量删除查获记录
     *
     * @param ids 需要删除的查获记录主键
     * @return 结果
     */
    public int deleteItemSeizureRecordByIds(Long[] ids);

    /**
     * 删除查获记录信息
     *
     * @param id 查获记录主键
     * @return 结果
     */
    public int deleteItemSeizureRecordById(Long id);
}
